Shiny for Python
================

See the [Shiny for Python website](https://shiny.rstudio.com/py/).


## Development

If you want to do development on Shiny for Python:

```sh
pip install -r requirements-dev.txt
```

Additionally, you can install pre-commit hooks which will automatically reformat and lint the code when you make a commit:

```sh
pre-commit install

# To disable:
# pre-commit uninstall
```
